@@ -2,6 +2,7 @@
 
 import tempfile
 from pathlib import Path
+from typing import Sequence, Union
 
 import numpy as np
 
@@ -42,7 +43,6 @@ def _random_patch(starttime="2017-09-18", network="", station="", tag="random"):
         d_distance=1,
         d_time=to_timedelta64(1 / 250),
         category="DAS",
-        id="test_data1",
         time_min=t1,
         network=network,
         station=station,
@@ -59,10 +59,11 @@ def _random_patch(starttime="2017-09-18", network="", station="", tag="random"):
 @register_func(EXAMPLE_PATCHES, key="sin_wav")
 def sin_wave_patch(
     sample_rate=44100,
-    frequency=100,
+    frequency: Union[Sequence[float], float] = 100.0,
     time_min="2020-01-01",
     channel_count=3,
     duration=1,
+    amplitude=10,
 ):
     """
     Return a Patch composed of simple 1 second sin waves.
@@ -81,13 +82,19 @@ def sin_wave_patch(
         The number of  distance channels to include.
     duration
         Duration of signal in seconds.
-
+    amplitude
+        The amplitude of the sin wave.
     """
     t_array = np.linspace(0.0, duration, sample_rate * duration)
-    sin_data = 10 * np.sin(2.0 * np.pi * frequency * t_array)
-    data = np.stack([sin_data] * channel_count).T
-    time = to_timedelta64(t_array) + np.datetime64(time_min)
+    # Get time and distance coords
     distance = np.arange(1, channel_count + 1, 1)
+    time = to_timedelta64(t_array) + np.datetime64(time_min)
+    freqs = [frequency] if isinstance(frequency, (float, int)) else frequency
+    # init empty data and add frequencies.
+    data = np.zeros((len(time), len(distance)))
+    for freq in freqs:
+        sin_data = amplitude * np.sin(2.0 * np.pi * freq * t_array)
+        data += sin_data[..., np.newaxis]
 
     patch = dc.Patch(
         data=data,
@@ -158,13 +165,13 @@ def _diverse_spool():
     spool_big_gaps = _random_spool(d_time=np.timedelta64(1, "s"), station="big_gaps")
     spool_overlaps = _random_spool(d_time=-np.timedelta64(10, "ms"), station="overlaps")
     dt = to_timedelta64(spool_big_gaps[0].attrs["d_time"] / np.timedelta64(1, "s"))
-    spool_small_gaps = _random_spool(d_time=dt, station="small_gaps")
+    spool_small_gaps = _random_spool(d_time=dt, station="smallg")
     spool_way_late = _random_spool(
-        length=1, starttime=np.datetime64("2030-01-01"), station="way_out"
+        length=1, starttime=np.datetime64("2030-01-01"), station="wayout"
     )
     spool_new_tag = _random_spool(tag="some_tag", length=1)
     spool_way_early = _random_spool(
-        length=1, starttime=np.datetime64("1989-05-04"), station="way_out"
+        length=1, starttime=np.datetime64("1989-05-04"), station="wayout"
     )
 
     all_spools = [
