@@ -1,4 +1,2 @@
-"""
-Utilities for dascore
-"""
+"""Utilities for dascore."""
 from .time import to_datetime64, to_timedelta64
