@@ -60,7 +60,7 @@ class TestFileIndex:
 
     def test_index_columns(self, basic_index_df):
         """Ensure expected columns show up in the index."""
-        schema_fields = PatchFileSummary.__fields__
+        schema_fields = PatchFileSummary.get_index_columns()
         assert set(basic_index_df).issuperset(schema_fields)
 
     def test_patches_extracted(self, basic_file_spool):
@@ -77,6 +77,14 @@ class TestFileIndex:
         # ensure the default str is not used.
         assert "object at" not in out
 
+    def test_long_tags(self, random_patch, tmp_path):
+        """Ensure a long tag still works."""
+        new = random_patch.update_attrs(tag="hey" * 15)
+        path = tmp_path / "test.h5"
+        new.io.write(path, "dasdae")
+        spool = dc.spool(path).update()
+        isinstance(spool, dc.BaseSpool)
+
 
 class TestSelect:
     """tests for subselecting data."""
